@@ -86,8 +86,9 @@ flow <- function(aoi, min_jam_factor = 0, url_only = FALSE) {
   }
 
   # Request and get content
-  data <- .get_content(
-    url = url
+  data <- .async_request(
+    url = url,
+    rps = Inf
   )
   if (length(data) == 0) {
     return(NULL)
